@@ -1,16 +1,16 @@
 package Perinci::Sub::ArgEntity::filename;
 
-our $DATE = '2015-09-06'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2015-09-17'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 
-use Complete::Util ();
+use Complete::File ();
 
 sub complete_arg_val {
-    Complete::Util::complete_file(@_);
+    Complete::File::complete_file(@_);
 }
 
 1;
@@ -28,7 +28,7 @@ Perinci::Sub::ArgEntity::filename - Data and code related to function arguments
 
 =head1 VERSION
 
-This document describes version 0.02 of Perinci::Sub::ArgEntity::filename (from Perl distribution Perinci-Sub-ArgEntity-filename), released on 2015-09-06.
+This document describes version 0.03 of Perinci::Sub::ArgEntity::filename (from Perl distribution Perinci-Sub-ArgEntity-filename), released on 2015-09-17.
 
 =for Pod::Coverage ^(.+)$
 
